@@ -3,7 +3,7 @@ package CSS::Parse::Packed;
 use warnings;
 use strict;
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 use base qw/CSS::Parse/;
 use Carp;
@@ -27,12 +27,12 @@ sub _parse_string {
 
     for my $str (grep { /\S/ } split /(?<=\})/, $string) {
         my ($selectors, $properties) = $str =~ m/^\s*([^{]+?)\s*\{(.*)\}\s*$/
-            or carp "Invalid style data '$_'", next;
+            or carp "Invalid style data '$str'", next;
 
         my @selectors = split /\s*,\s*/, $selectors;
         for my $property (grep { /\S/ } split /\;/, $properties) {
             my ($name, $val) = $property =~ m/^\s*([\w._-]+)\s*:\s*(.*?)\s*$/
-                or carp "Invalid property '$_'", next;
+                or carp "Invalid property '$property'", next;
             for my $selector (@selectors) {
                 $self->stash->{$selector}->{$name} = $val;
             }
